==> scala-k8s-objects_2.12-0.3.0-sources.jar: io/k8s/api/core/v1/TCPSocketAction.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s.utils._

/** TCPSocketAction describes an action based on opening a socket */
final case class TCPSocketAction(
  port : io.k8s.apimachinery.pkg.util.intstr.IntOrString,
  host : Option[String] = None
) {

  /** Returns a new data with port set to new value */
  def withPort(value: io.k8s.apimachinery.pkg.util.intstr.IntOrString) : TCPSocketAction = copy(port = value)
  /** transforms port to result of function */
  def mapPort(f: io.k8s.apimachinery.pkg.util.intstr.IntOrString => io.k8s.apimachinery.pkg.util.intstr.IntOrString) : TCPSocketAction = copy(port = f(port))

  /** Returns a new data with host set to new value */
  def withHost(value: String) : TCPSocketAction = copy(host = Some(value))
  /** if host has a value, transforms to the result of function*/
  def mapHost(f: String => String) : TCPSocketAction = copy(host = host.map(f))
}

object TCPSocketAction {

    implicit def encoder[T](implicit builder : Builder[T]) : Encoder[io.k8s.api.core.v1.TCPSocketAction, T] = new Encoder[io.k8s.api.core.v1.TCPSocketAction, T] {
        def apply(o: io.k8s.api.core.v1.TCPSocketAction) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("port", o.port)
            .write("host", o.host)
            .build
        }
    }

    implicit def decoderOf[T : Reader] : Decoder[T, TCPSocketAction] = new Decoder[T, TCPSocketAction] {
      def apply(t: T): Either[String, TCPSocketAction] = for {
          obj <- ObjectReader(t)
          port <- obj.read[io.k8s.apimachinery.pkg.util.intstr.IntOrString]("port")
          host <- obj.readOpt[String]("host")
      } yield TCPSocketAction (
          port = port,
          host = host
        )
    }
}

==> scala-k8s-objects_2.13-0.18.0-sources.jar: io/k8s/api/core/v1/TCPSocketAction.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s.utils._

/** TCPSocketAction describes an action based on opening a socket */
final case class TCPSocketAction(
  port : io.k8s.apimachinery.pkg.util.intstr.IntOrString,
  host : Option[String] = None
) {

  /** Returns a new data with port set to new value */
  def withPort(value: io.k8s.apimachinery.pkg.util.intstr.IntOrString) : TCPSocketAction = copy(port = value)
  /** transforms port to result of function */
  def mapPort(f: io.k8s.apimachinery.pkg.util.intstr.IntOrString => io.k8s.apimachinery.pkg.util.intstr.IntOrString) : TCPSocketAction = copy(port = f(port))

  /** Returns a new data with host set to new value */
  def withHost(value: String) : TCPSocketAction = copy(host = Some(value))
  /** if host has a value, transforms to the result of function*/
  def mapHost(f: String => String) : TCPSocketAction = copy(host = host.map(f))
}

object TCPSocketAction {

    implicit val encoder : Encoder[io.k8s.api.core.v1.TCPSocketAction] = new Encoder[io.k8s.api.core.v1.TCPSocketAction] {
        def apply[T : Builder](o: io.k8s.api.core.v1.TCPSocketAction) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("port", o.port)
            .write("host", o.host)
            .build
        }
    }

    implicit val decoder: Decoder[TCPSocketAction] = new Decoder[TCPSocketAction] {
      def apply[T : Reader](t: T): Either[String, TCPSocketAction] = for {
          obj <- ObjectReader(t)
          port <- obj.read[io.k8s.apimachinery.pkg.util.intstr.IntOrString]("port")
          host <- obj.readOpt[String]("host")
      } yield TCPSocketAction (
          port = port,
          host = host
        )
    }
}
